@@ -1,5 +1,5 @@
 
-# $rcs = ' $Id: Listing.pm,v 1.9 2008/03/02 18:16:27 Daddy Exp $ ' ;
+# $rcs = ' $Id: Listing.pm,v 1.11 2010-03-06 13:33:21 Martin Exp $ ' ;
 
 =head1 COPYRIGHT
 
@@ -12,16 +12,9 @@ WWW/Ebay/Listing.pm
 
 =head1 SYNOPSIS
 
-=begin example
-
   use WWW::Ebay::Listing;
   my $oWEL = new WWW::Ebay::Listing;
 
-=end example
-
-=for example_testing
-ok(ref $oWEL);
-
 =head1 DESCRIPTION
 
 Encapsulates a posted / running / completed auction listing at the
@@ -35,7 +28,7 @@ use strict;
 use warnings;
 
 our
-$VERSION = do { my @r = (q$Revision: 1.9 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.11 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
 use Carp;
 use WWW::Ebay::Status;
@@ -238,19 +231,9 @@ sub ended
 
 =back
 
-=head1 NOTES
-
-=head1 CAVEATS
-
-=head1 DIAGNOSTICS
-
-=head1 BUGS
-
-=head1 RESTRICTIONS
-
 =head1 AUTHOR
 
-Martin Thurn, C<mthurn@cpan.org>, L<http://www.sandcrawler.com/SWB/cpan-modules.html>.
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 =cut
 
