@@ -1,5 +1,5 @@
 
-# $rcs = ' $Id: Session.pm,v 1.56 2008/04/06 03:35:48 Martin Exp $ ' ;
+# $rcs = ' $Id: Session.pm,v 1.59 2010-03-06 13:33:22 Martin Exp $ ' ;
 
 =head1 COPYRIGHT
 
@@ -22,7 +22,7 @@ webpages from the eBay auction website (www.ebay.com).
 
 =head1 AUTHOR
 
-Martin Thurn, C<mthurn@cpan.org>, L<http://www.sandcrawler.com/SWB/cpan-modules.html>.
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 =head1 METHODS
 
@@ -62,6 +62,9 @@ use constant DEBUG_UNSOLD => 0;
 use constant DEBUG_WATCH => 0;
 use constant DEBUG_READ_LOCAL_FILES => 0;
 
+our
+$VERSION = do { my @r = (q$Revision: 1.59 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+
 sub _debug
   {
   # return unless $iDEBUGGING;
@@ -240,9 +243,8 @@ sub fetch_any_ebay_page
       } # if
     return '';
     } # unless
-  $sRes = $self->response->headers_as_string;
   $sPage = $self->response->content;
-  if ($sPage =~ m!"PageSignIn"!)
+  if ($sPage =~ m!"SignInForm"!)
     {
     # We need to sign-in before we get to see the requested page:
     my $fname1 = "Pages/$sName-signin.html";
